@@ -36,14 +36,16 @@ update_kim <- function(
   confirm = TRUE) {
   # 6 possible cases
   # 1. error in getting the current package version -> yes
-  # 2. error in getting the github package version -> yes
+  # 2. error in getting the github package version -> no
+  #    -> this used to be "yes," but as of aug 22, 2023, it's now "no"
   # 3. current package version < github package version -> yes
   # 4. current package version > github package version -> no
   # 5. current package version == github package version -> no
   # 6. the user forces the update -> yes
   # in short, notify the option to update unless the version numbers match
-
-  # update if user wants the update
+  #
+  # case 6. the user forces the update -> yes
+  # i.e., update if the user wants an update
   if (force == TRUE) {
     # unload the package kim
     while ("package:kim" %in% search()) {
@@ -67,56 +69,64 @@ update_kim <- function(
       readLines(github_url),
       warning = function(w) {"github_desc_read_fail"},
       error = function(e) {"github_desc_read_fail"})
+    if (!identical(github_pkg_desc, "github_desc_read_fail")) {
+      github_pkg_version <- "unknown"
+    }
     # get the version number of github version
     if (identical(github_pkg_desc, "github_desc_read_fail")) {
+      # case 2. error in getting the github package version -> no
       github_pkg_version <- "unknown"
     } else {
       github_pkg_version <- gsub(
         ".*ersion: ", "", github_pkg_desc[
           grep("ersion", github_pkg_desc)])
-    }
-    # compare versions
-    compare_version_result <- tryCatch(
-      utils::compareVersion(
-        current_pkg_version, github_pkg_version),
-      warning = function(w) {999}, # 999 indicates no need for update
-      error = function(e) {999})
-    # skip update for case 5
-    if (current_pkg_version != "unknown" &
+      # cases 1, 3-5.
+      # compare versions
+      compare_version_result <- tryCatch(
+        utils::compareVersion(
+          current_pkg_version, github_pkg_version),
+        warning = function(w) {999}, # 999 indicates no need for update
+        error = function(e) {999})
+      # 5. current package version == github package version -> no
+      # skip update for case 5
+      if (current_pkg_version != "unknown" &
+          github_pkg_version != "unknown" &
+          compare_version_result == 0) {
+        message(paste0(
+          "Current version of 'kim': v", current_pkg_version,
+          " (same as the most recent version available through GitHub)."))
+      } else if (
+        # 4. current package version > github package version -> no
+        # skip update for case 4
+        current_pkg_version != "unknown" &
         github_pkg_version != "unknown" &
-        compare_version_result == 0) {
-      message(paste0(
-        "Current version of 'kim': v", current_pkg_version,
-        " (same as the most recent version available through GitHub)."))
-    } else if (
-      # skip update for case 4
-      current_pkg_version != "unknown" &
-      github_pkg_version != "unknown" &
-      compare_version_result > 0) {
-      message(paste0(
-        "Current version of 'kim': v", current_pkg_version,
-        " (probably the most recent version available through GitHub)."))
-    } else {
-      # confirm update
-      if (confirm == TRUE) {
-        # ask the user to confirm
-        user_reply <- utils::menu(
-          c("Yes.", "No."),
-          title = "\nDo you want to try to update the package 'kim'?")
+        compare_version_result > 0) {
+        message(paste0(
+          "Current version of 'kim': v", current_pkg_version,
+          " (probably the most recent version available through GitHub)."))
       } else {
-        # if not asked, assume the user wants to update
-        user_reply <- 1
-      }
-      # update if user wants the update
-      if (user_reply == 1) {
-        # unload the package kim
-        while ("package:kim" %in% search()) {
-          unloadNamespace("kim")
+        # cases 1 and 3.
+        # confirm update
+        if (confirm == TRUE) {
+          # ask the user to confirm
+          user_reply <- utils::menu(
+            c("Yes.", "No."),
+            title = "\nDo you want to try to update the package 'kim'?")
+        } else {
+          # if not asked, assume the user wants to update
+          user_reply <- 1
+        }
+        # update if user wants the update
+        if (user_reply == 1) {
+          # unload the package kim
+          while ("package:kim" %in% search()) {
+            unloadNamespace("kim")
+          }
+          remotes::install_github(
+            "jinkim3/kim", force = force, upgrade = upgrade_other_pkg)
+          # attach the package
+          kim::prep("kim", silent_if_successful = TRUE)
         }
-        remotes::install_github(
-          "jinkim3/kim", force = force, upgrade = upgrade_other_pkg)
-        # attach the package
-        kim::prep("kim", silent_if_successful = TRUE)
       }
     }
   }
